@@ -17,8 +17,9 @@
     Changes:
 */
 
-#include <MagLog.h>
+#include "MagLog.h"
 #include <algorithm>
+#include "MagException.h"
 #include "MagicsObserver.h"
 
 using namespace magics;
@@ -27,6 +28,7 @@ MagLog MagLog::log_;
 bool MagLog::header_;
 
 namespace magics {
+
 class MagLogObserver : public ostringstream {
 public:
     MagLogObserver() : silent_(false) {}
@@ -105,8 +107,6 @@ public:
     LOG callback_;
 };
 
-}  // namespace magics
-
 static MagLogObserver MYLOG;
 
 
@@ -365,3 +365,49 @@ void MagLog::unregisterObserver(MagicsObserver* observer) {
     if (o != log_.observers_.end())
         log_.observers_.erase(o);
 }
+
+
+void MagLog::devMessage(bool dev) {
+    log_.dev_ = dev;
+}
+
+void MagLog::infoMessage(bool info) {
+    log_.info_ = info;
+}
+
+void MagLog::userInfoMessage(bool info) {
+    log_.userInfo_ = info;
+}
+
+void MagLog::warningMessage(bool warning) {
+    log_.warning_ = warning;
+}
+
+void MagLog::debugMessage(bool debug) {
+    log_.debug_ = debug;
+}
+
+void MagLog::errorMessage(bool error) {
+    log_.error_ = error;
+}
+
+void MagLog::profilingMessage(bool error) {
+    log_.error_ = error;
+}
+
+void MagLog::fatalMessage(bool fatal) {
+    log_.fatal_ = fatal;
+}
+
+void MagLog::header(bool header) {
+    header_ = header;
+}
+
+void MagLog::setReporter(const ErrorReporter* reporter) {
+    log_.reporter_ = reporter;
+}
+void MagLog::registerObserver(MagicsObserver* observer) {
+    log_.observers_.push_back(observer);
+}
+
+}  // namespace magics
