@@ -190,7 +190,7 @@ void NetDimension::last(const string& val) {
 
 
 NetVariable::NetVariable(const string& name, int id, Netcdf* parent, const string& method) :
-    name_(name), id_(id), parent_(parent) {
+    name_(name), id_(id), parent_(parent), missing_(std::numeric_limits<double>::max()) {
     netcdf_ = parent_->file();
     int num_dims;
     nc_inq_varndims(netcdf_, id_, &num_dims);
@@ -288,7 +288,7 @@ string NetVariable::interpretTime(const string& val) {
 
         return tostring(diff);
     }
-    catch (exception) {
+    catch (...) {
         return val;
     }
 }
@@ -297,15 +297,14 @@ int NetVariable::find(const string& value) {
     // First , is the variable a time variable:
 
     string val = value;
-   
+
     try {
         val = interpretTime(value);
     }
     catch (...) {
         val = value;
     }
-    
-   
+
 
     nc_type t = type();
     if (t == NC_DOUBLE) {
@@ -358,7 +357,7 @@ int NetVariable::find(const string& value) {
         for ( int i = 0; i < dims[0]; i++ ) {
             char text[256];
             nc_get_var_text(netcdf_, id_, text);
-            if (string(text) ==  val)       
+            if (string(text) ==  val)
                 return i;
 
         }
@@ -366,26 +365,39 @@ int NetVariable::find(const string& value) {
 
     if (t == NC_STRING) {
         int x = getSize();
-        char *values[x];
+        char* values[1024];
+        ASSERT(x < sizeof(values));
         nc_get_var_string(netcdf_, id_, values);
         for (int i = 0; i < x; i++) {
-           
-            if (string(values[i]) == val) 
-                return i; 
+            if (string(values[i]) == val)
+                return i;
         }
-        
+
     }
-    
+
     return 0;
 }
 
 
 double NetVariable::getDefaultMissing() {
-    if (type() == NC_DOUBLE)
-        return NC_FILL_DOUBLE;
-    if (type() == NC_BYTE)
-        return NC_FILL_BYTE;
+    int t = type();
+    switch(t) {
+        case NC_CHAR: return NC_FILL_CHAR; break;
+        case NC_BYTE: return NC_FILL_BYTE; break;
+        case NC_UBYTE: return NC_FILL_UBYTE; break;
+        case NC_INT: return NC_FILL_INT; break;
+        case NC_UINT: return NC_FILL_UINT; break;
+        case NC_SHORT: return NC_FILL_SHORT; break;
+        case NC_USHORT: return NC_FILL_USHORT; break;
+        case NC_INT64: return NC_FILL_INT64; break;
+        case NC_UINT64: return NC_FILL_UINT64; break;
+        case NC_FLOAT: return NC_FILL_FLOAT; break;
+        case NC_DOUBLE: return NC_FILL_DOUBLE; break;
+    }
+
+    MagLog::warning() << "NetVariable: No default missing value defined for " << nc_type_to_name(t) << std::endl;
     return NC_FILL_FLOAT;
+
 }
 
 
@@ -445,3 +457,27 @@ static TypedAccessor<int, double> int_double_accessor(NC_INT);
 static TypedAccessor<float, double> float_double_accessor(NC_FLOAT);
 static TypedAccessor<double, double> double_double_accessor(NC_DOUBLE);
 
+namespace magics {
+
+const char* nc_type_to_name(int n) {
+
+    switch (n) {
+        case NC_CHAR: return "NC_CHAR"; break;
+        case NC_BYTE: return "NC_BYTE"; break;
+        case NC_UBYTE: return "NC_UBYTE"; break;
+        case NC_INT: return "NC_INT"; break;
+        case NC_UINT: return "NC_UINT"; break;
+        case NC_SHORT: return "NC_SHORT"; break;
+        case NC_USHORT: return "NC_USHORT"; break;
+        case NC_INT64: return "NC_INT64"; break;
+        case NC_UINT64: return "NC_UINT64"; break;
+        case NC_FLOAT: return "NC_FLOAT"; break;
+        case NC_DOUBLE: return "NC_DOUBLE"; break;
+        case NC_STRING: return "NC_STRING"; break;
+    }
+
+    static char unknown[20];
+    sprintf(unknown, "UNKNOWN(%d)", n);
+    return unknown;
+}
+}
